@@ -1,4 +1,4 @@
-#![doc = include_str!("lib.md")]
+#![doc = include_str!("../README.md")]
 #![forbid(unsafe_code)]
 #![no_std]
 
